[Slim-Checkins] r10025 - in /trunk/server: Changelog6.html Slim/Player/Squeezebox.pm

andy at svn.slimdevices.com andy at svn.slimdevices.com
Mon Sep 25 07:29:04 PDT 2006


Author: andy
Date: Mon Sep 25 07:29:02 2006
New Revision: 10025

URL: http://svn.slimdevices.com?rev=10025&view=rev
Log:
Bug 4149, show buffering status on Now Playing screen

Modified:
    trunk/server/Changelog6.html
    trunk/server/Slim/Player/Squeezebox.pm

Modified: trunk/server/Changelog6.html
URL: http://svn.slimdevices.com/trunk/server/Changelog6.html?rev=10025&r1=10024&r2=10025&view=diff
==============================================================================
--- trunk/server/Changelog6.html (original)
+++ trunk/server/Changelog6.html Mon Sep 25 07:29:02 2006
@@ -5,6 +5,7 @@
 		<li><a href="http://bugs.slimdevices.com/show_bug.cgi?id=4077">#4077</a> - CUE files YEAR and GENRE not always working</li>
 		<li><a href="http://bugs.slimdevices.com/show_bug.cgi?id=4140">#4140</a> - Problem with the scanner parsing cue sheets in6.5b3</li>
 		<li><a href="http://bugs.slimdevices.com/show_bug.cgi?id=4142">#4142</a> - ExBrowse3 does not work with Safari</li>
+		<li><a href="http://bugs.slimdevices.com/show_bug.cgi?id=4149">#4149</a> - Display buffering feedback on Now Playing screen even after IR</li>
 		<li><a href="http://bugs.slimdevices.com/show_bug.cgi?id=4156">#4156</a> - slimtray should install the service if it's not already installed when starting</li>
 		<li><a href="http://bugs.slimdevices.com/show_bug.cgi?id=4168">#4168</a> - Live365 plugin fails in 6.5.0</li>
 		<li><a href="http://bugs.slimdevices.com/show_bug.cgi?id=4171">#4171</a> - Default2 redirect to Default.</li>

Modified: trunk/server/Slim/Player/Squeezebox.pm
URL: http://svn.slimdevices.com/trunk/server/Slim/Player/Squeezebox.pm?rev=10025&r1=10024&r2=10025&view=diff
==============================================================================
--- trunk/server/Slim/Player/Squeezebox.pm (original)
+++ trunk/server/Slim/Player/Squeezebox.pm Mon Sep 25 07:29:02 2006
@@ -281,9 +281,11 @@
 			$line2  = Slim::Music::Info::title( $url );
 		}
 		
-		# Only show buffering status if no user activity on player
-		my $lastIR = Slim::Hardware::IR::lastIRTime($client) || 0;
-		if ( $lastIR < $buffering->{$client} ) {
+		# Only show buffering status if no user activity on player or we're on the Now Playing screen
+		my $nowPlaying = Slim::Buttons::Playlist::showingNowPlaying($client);
+		my $lastIR     = Slim::Hardware::IR::lastIRTime($client) || 0;
+		
+		if ( $nowPlaying || $lastIR < $buffering->{$client} ) {
 			$client->showBriefly( $line1, $line2, 0.5 ) unless $client->display->sbName();
 		}
 		



More information about the checkins mailing list